==> RosterServer-0.15.tar.gz: RosterServer-0.15/roster_server/auth_pam.py <==
#!/usr/bin/python

# Copyright (c) 2009, Purdue University
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#
# Redistributions of source code must retain the above copyright notice, this
# list of conditions and the following disclaimer.
#
# Redistributions in binary form must reproduce the above copyright notice, this
# list of conditions and the following disclaimer in the documentation and/or
# other materials provided with the distribution.
#
# Neither the name of the Purdue University nor the names of its contributors
# may be used to endorse or promote products derived from this software without
# specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
# DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
# FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
# DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
# SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
# CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
# OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

"""PAM module for Pluggable Authentication Module in RosterServer."""

__copyright__ = 'Copyright (C) 2010, Purdue Univeristy'
__license__ = 'BSD'
__version__ = '0.15'

## http://pypi.python.org/pypi/pam/
import pam


class PAMInputError(Exception):
  pass


class AuthenticationMethod:
  """PAM authentication method,"""
  def __init__(self, module=pam):
    self.requires ={}
    self.module = module

  def Authenticate(self, username=None, password=None):
    """Check, using PAM, if the user_name and password provided match.
    Inputs:
      user_name: string of user name.
      password: string of password

    Outputs:
      boolean: authentication success
    """
    if ((not username) or (not password)):
      authenticated = false
    else:
      authenticated = self.module.authenticate(username, password, 'passwd')
    return authenticated

==> RosterServer-0.16.tar.gz: RosterServer-0.16/roster_server/auth_pam.py <==
#!/usr/bin/python

# Copyright (c) 2009, Purdue University
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#
# Redistributions of source code must retain the above copyright notice, this
# list of conditions and the following disclaimer.
#
# Redistributions in binary form must reproduce the above copyright notice, this
# list of conditions and the following disclaimer in the documentation and/or
# other materials provided with the distribution.
#
# Neither the name of the Purdue University nor the names of its contributors
# may be used to endorse or promote products derived from this software without
# specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
# DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
# FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
# DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
# SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
# CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
# OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

"""PAM module for Pluggable Authentication Module in RosterServer."""

__copyright__ = 'Copyright (C) 2010, Purdue Univeristy'
__license__ = 'BSD'
__version__ = '0.16'

## http://pypi.python.org/pypi/pam/
import pam


class PAMInputError(Exception):
  pass


class AuthenticationMethod:
  """PAM authentication method,"""
  def __init__(self, module=pam):
    self.requires = {}
    self.module = module

  def Authenticate(self, user_name=None, password=None):
    """Check, using PAM, if the user_name and password provided match.
    Inputs:
      user_name: string of user name.
      password: string of password

    Outputs:
      boolean: authentication success
    """
    if ((not user_name) or (not password)):
      authenticated = False
    else:
      authenticated = self.module.authenticate(user_name, password, 'passwd')
    return authenticated
